@@ -231,6 +231,13 @@ class HydraPy:
 
     _message_handler = None
 
+    INFO = 'info'
+    DEBUG = 'debug'
+    WARN = 'warn'
+    ERROR = 'error'
+    FATAL = 'fatal'
+    TRACE = 'trace'
+
     def __init__(self, config_path, version, message_handler):
         if message_handler:
             self._message_handler = message_handler
@@ -434,6 +441,25 @@ class HydraPy:
         await tr.execute()
         await asyncio.gather(f1, f2)
 
+    async def log(self, severity, entry, text=None):
+        entry = {
+            'serviceName': self._service_name,
+            'version': self._service_version,
+            'instanceID': self._instance_id,
+            'severity': severity,
+            'body': {}
+        }
+        if text:
+            entry['message'] = text
+        if entry:
+            entry['body'] = entry
+        msg = (UMF_Message()).create_message({
+            'to': 'hydra-logging-svcs:/',
+            'from': f'{self._service_name}:/',
+            'body': entry
+        })
+        await self.send_message(msg)
+
     async def _health_check_event(self):
         tr = self._redis.multi_exec()
         f1 = tr.setex(f'{self._redis_pre_key}:{self._service_name}:{self._instance_id}:health',
